@@ -1,22 +1,22 @@
 /** @file
 	Parser: @b dnode methods class - MDnode class decl.
 
-	Copyright (c) 2001-2005 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef XNODE_H
 #define XNODE_H
 
-static const char * const IDENT_XNODE_H="$Date: 2007-04-23 10:30:10 $";
+static const char * const IDENT_XNODE_H="$Date: 2009-08-08 13:30:21 $";
 
 class MXnode: public Methoded {
 public: // Value
 
 	/// MXnode: +$const
-	Value* get_element(const String& aname, Value& aself, bool looking_up) {
+	Value* get_element(const String& aname) {
 		// $method
-		if(Value* result=Methoded::get_element(aname, aself, looking_up))
+		if(Value* result=Methoded::get_element(aname))
 			return result;
 
 		// $const
@@ -28,7 +28,7 @@ public: // Value
 
 
 public: // VStateless_class
-	Value* create_new_value(Pool&, HashStringValue&) { 
+	Value* create_new_value(Pool&) { 
 		throw Exception(PARSER_RUNTIME,
 			0,
 			"no constructors available, use CreateXXX DOM methods to create nodes instead"); 
