@@ -8,7 +8,7 @@
 #ifndef PA_COMMON_H
 #define PA_COMMON_H
 
-static const char * const IDENT_COMMON_H="$Date: 2009-10-06 11:39:02 $";
+static const char * const IDENT_COMMON_H="$Date: 2011-02-18 06:01:21 $";
 
 #include "pa_string.h"
 #include "pa_hash.h"
@@ -252,7 +252,7 @@ const char* format(double value, char *fmt);
 
 size_t stdout_write(const void *buf, size_t size);
 
-char* unescape_chars(const char* cp, int len, Charset* client_charset=0, bool ignore_plus=false);
+char* unescape_chars(const char* cp, int len, Charset* client_charset=0, bool js=false/*true==decode \uXXXX and don't convert '+' to space*/);
 
 #ifdef WIN32
 void back_slashes_to_slashes(char *s);
@@ -274,9 +274,15 @@ int getMonthDays(int year, int month);
 
 int remove_crlf(char *start, char *end);
 
-#ifdef PA_SAFE_MODE 
+inline bool pa_isalpha(unsigned char c) {
+	return (((c>='A') && (c<='Z')) || ((c>='a') && (c<='z')));
+}
+
+inline bool pa_isalnum(unsigned char c) {
+	return (((c>='0') && (c<='9')) || pa_isalpha(c));
+}
+
 void check_safe_mode(struct stat finfo, const String& file_spec, const char* fname); 
-#endif 
 
 void pa_base64_decode(const char *in, size_t in_size, char*& result, size_t& result_size);
 char* pa_base64_encode(const char *in, size_t in_size);
@@ -378,6 +384,20 @@ static String::C date_gmt_string(tm* tms) {
 		tms->tm_hour,tms->tm_min,tms->tm_sec));
 }
 
+static int lastposafter(const String& s, size_t after, const char* substr, size_t substr_size, bool beforelast=false) {
+	size_t size=0; // just to calm down compiler
+	if(beforelast)
+		size=s.length();
+	size_t at;
+	while((at=s.pos(String::Body(substr), after))!=STRING_NOT_FOUND) {
+		size_t newafter=at+substr_size/*skip substr*/;
+		if(beforelast && newafter==size)
+			break;
+		after=newafter;
+	}
+
+	return after;
+}
 
 // globals
 
