@@ -8,7 +8,7 @@
 #ifndef PA_EXCEPTION_H
 #define PA_EXCEPTION_H
 
-static const char * const IDENT_EXCEPTION_H="$Date: 2009-09-08 09:07:51 $";
+static const char * const IDENT_EXCEPTION_H="$Date: 2010-07-05 05:48:26 $";
 
 const char* const PARSER_RUNTIME = "parser.runtime";
 const char* const IMAGE_FORMAT = "image.format";
@@ -30,8 +30,10 @@ const char* const FIRST_ARG_MUST_NOT_BE_CODE = "first argument must not be code"
 const char* const PARAM_MUST_NOT_BE_CODE = "param must not be code";
 const char* const MODE_MUST_NOT_BE_CODE = "mode must not be code";
 const char* const OPTIONS_MUST_NOT_BE_CODE = "options must not be code";
+const char* const OPTIONS_MUST_BE_HASH_NOT_CODE = "options must be hash, not code";
+const char* const OPTIONS_MUST_BE_HASH = "options must be hash";
 
-const char* const INVALID_OPTION_PASSED = "invalid option passed";
+const char* const CALLED_WITH_INVALID_OPTION = "called with invalid option";
 
 // includes
 
