@@ -8,7 +8,7 @@
 #ifndef PA_STRING_H
 #define PA_STRING_H
 
-static const char * const IDENT_STRING_H="$Date: 2009-11-09 00:37:44 $";
+static const char * const IDENT_STRING_H="$Date: 2010-10-16 22:24:20 $";
 
 // includes
 #include "pa_types.h"
@@ -103,11 +103,11 @@ public:
 		L_URI='U',			///< text in uri
 		L_SQL='Q',			///< ^table:sql body
 		L_JS='J',			///< JavaScript code
-		L_XML='X',			///< ^dom:set xml
+		L_XML='X',			///< ^xdoc:create xml
 		L_HTML='H',			///< HTML code
-		L_REGEX='R',		///< RegEx expression
+		L_REGEX='R',		///< RegExp
+		L_JSON='S',			///< JSON code
 		L_HTTP_COOKIE='C',	///< cookies encoded as %uXXXX for compartibility with js functions encode/decode
-		L_FILE_POST='f',	///< temporary escaping zero-char
 		L_PARSER_CODE='p',	///< ^process body
 		// READ WARNING ABOVE BEFORE ADDING ANYTHING
 		L_OPTIMIZE_BIT = 0x80  ///< flag, requiring cstr whitespace optimization
@@ -580,6 +580,14 @@ public:
 	String& append(const String& src, Language lang, bool forced=false) { 
 		return src.append_to(*this, lang, forced);
 	}
+	String& append_quoted(const String* src, Language lang=L_JSON){
+		*this << "\"";
+		if(src)
+			this->append(*src, lang, true/*forced lang*/);
+		*this << "\"";
+		return *this;
+	}
+
 	String& operator << (const String& src) { return append(src, L_PASS_APPENDED); }
 	String& operator << (const char* src) { return append_help_length(src, 0, L_AS_IS); }
 	String& operator << (const Body& src){
