@@ -8,7 +8,7 @@
 #ifndef PA_VALUE_H
 #define PA_VALUE_H
 
-static const char * const IDENT_VALUE_H="$Date: 2009-09-18 09:16:07 $";
+static const char * const IDENT_VALUE_H="$Date: 2010-11-03 22:08:44 $";
 
 #include "pa_common.h"
 #include "pa_array.h"
@@ -32,6 +32,51 @@ class VFile;
 class Table;
 typedef Array<Value*> ArrayValue;
 
+struct Json_options {
+	Request* r;
+	HashStringValue* methods;
+	Value* params;
+	bool skip_unknown;
+	const char* indent;
+	enum Date { D_SQL, D_GMT, D_TIMESTAMP } date;
+	enum Table { T_ARRAY, T_OBJECT, T_COMPACT } table;
+	enum File { F_BODYLESS, F_BASE64, F_TEXT } file;
+
+	Json_options(Request* arequest): 
+		r(arequest),
+		methods(NULL),
+		params(NULL),
+		skip_unknown(false),
+		indent(NULL),
+		date(D_SQL),
+		table(T_OBJECT),
+		file(F_BODYLESS)
+	{}
+
+	bool set_date_format(const String &value){
+		if(value == "gmt-string") date = D_GMT;
+		else if (value == "sql-string") date = D_SQL;
+		else if (value == "unix-timestamp") date = D_TIMESTAMP;
+		else return false;
+		return true;
+	}
+
+	bool set_table_format(const String &value){
+		if(value == "array") table = T_ARRAY;
+		else if (value == "object") table = T_OBJECT;
+		else if (value == "compact") table = T_COMPACT;
+		else return false;
+		return true;
+	}
+
+	bool set_file_format(const String &value){
+		if(value == "base64") file = F_BASE64;
+		else if (value == "text") file = F_TEXT;
+		else return false;
+		return true;
+	}
+};
+
 ///	grandfather of all @a values in @b Parser
 class Value: public PA_Object {
 public: // Value
@@ -79,6 +124,9 @@ public: // Value
 	/// extract const String
 	virtual const String* get_string() { return 0; }
 
+	/// extract json-string
+	virtual const String* get_json_string(Json_options* options=0);
+
 	virtual HashStringValue* get_fields() { return 0; }
 	
 	/// extract double
@@ -112,6 +160,13 @@ public: // Value
 		bark("element can not be stored to %s", &aname); 
 		return 0;
 	}
+
+	/// VObject default getter & setter support
+	virtual void enable_default_getter(){ }
+	virtual void enable_default_setter(){ }
+	virtual void disable_default_getter(){ }
+	virtual void disable_default_setter(){ }
+	virtual bool is_enabled_default_getter(){ return true; }
 	
 	/// extract VStateless_class
 	virtual VStateless_class* get_class()=0;
@@ -133,8 +188,6 @@ public: // usage
 		return *result;
 	}
 
-protected: 
-
 	/// throws exception specifying bark-reason and name() type() of problematic value
 	Value* bark(const char *reason, const String *problem_source=0) const {
 		//if(this) // removing warnings on unreachable code
