@@ -8,7 +8,7 @@
 #ifndef PA_VSTATELESS_CLASS_H
 #define PA_VSTATELESS_CLASS_H
 
-static const char * const IDENT_VSTATELESS_CLASS_H="$Date: 2009-08-14 10:39:48 $";
+static const char * const IDENT_VSTATELESS_CLASS_H="$Date: 2010-09-06 21:17:49 $";
 
 // include
 
@@ -49,6 +49,7 @@ class VStateless_class: public Value {
 	bool flocked;
 	bool fall_vars_local;
 	bool fpartial;
+	Method::Call_type fcall_type;
 
 protected:
 
@@ -58,6 +59,7 @@ protected:
 
 	Method* fscalar;
 	Method* fdefault_getter;
+	Method* fdefault_setter;
 
 public: // Value
 	
@@ -74,7 +76,10 @@ public: // Value
 
 	override const VJunction* put_element(const String& aname, Value* avalue, bool areplace) {	return put_element(*this, aname, avalue, areplace); }
 	/// put_element with aself for VObject junctions
-	virtual const VJunction* put_element(Value& /*aself*/, const String& aname, Value* avalue, bool areplace) {	return Value::put_element(aname, avalue, areplace); }
+	virtual const VJunction* put_element(Value& aself, const String& aname, Value* /*avalue*/, bool /*areplace*/) {	
+		aself.bark("element can not be stored to %s", &aname); 
+		return 0;
+	}
 
 	override Value& as_expr_result(bool /*return_string_as_is=false*/);
 
@@ -83,6 +88,11 @@ public: // Value
 
 	Value* get_default_getter(Value& aself, const String& aname);
 	void set_default_getter(Method* amethod);
+	bool has_default_getter();
+
+	VJunction* get_default_setter(Value& aself, const String& aname);
+	void set_default_setter(Method* amethod);
+	bool has_default_setter();
 
 	void add_derived(VStateless_class &aclass);
 
@@ -98,7 +108,9 @@ public: // usage
 		fall_vars_local(false),
 		fpartial(false),
 		fscalar(0),
-		fdefault_getter(0)
+		fdefault_getter(0),
+		fdefault_setter(0),
+		fcall_type(Method::CT_ANY)
 		{
 			set_base(abase);
 	}
@@ -152,6 +164,19 @@ public: // usage
 		fpartial=true;
 	}
 
+	Method::Call_type get_methods_call_type(){
+		return fcall_type;
+	}
+
+	void set_methods_call_type(Method::Call_type call_type){
+		if(fcall_type!=Method::CT_ANY)
+			throw Exception(PARSER_RUNTIME,
+						0,
+						"You can specify call type option in a class only once"
+					);
+		fcall_type=call_type;
+	}
+
 	void add_native_method(
 		const char* cstr_name,
 		Method::Call_type call_type,
