@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b stateless_object class decl.
 
-	Copyright (c) 2001-2005 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VSTATELESS_OBJECT_H
 #define PA_VSTATELESS_OBJECT_H
 
-static const char * const IDENT_VSTATELESS_OBJECT_H="$Date: 2008-06-16 12:41:34 $";
+static const char * const IDENT_VSTATELESS_OBJECT_H="$Date: 2009-08-08 13:30:22 $";
 
 // include
 
@@ -23,13 +23,13 @@ class VStateless_object: public Value {
 public: // Value
 	
 	/// VStateless_object: class_transparent
-	override Value* get_element(const String& aname, Value& aself, bool alooking_up) {
-		return get_class()->get_element(aname, aself, alooking_up);
+	override Value* get_element(const String& aname) {
+		return get_class()->get_element(*this, aname);
 	}
 
 	/// VStateless_object: class_transparent
-	override const VJunction* put_element(Value& aself, const String& aname, Value* avalue, bool areplace) { 
-		return get_class()->put_element(aself, aname, avalue, areplace);
+	override const VJunction* put_element(const String& aname, Value* avalue, bool areplace) { 
+		return get_class()->put_element(*this, aname, avalue, areplace);
 	}
 
 	/// VStateless_object: class_transparent
